=======
History
=======

0.2.0 (2020-02-18)
------------------
* Add support to process coco dataset


0.2.1 (2020-02-28)
------------------
* add support to download files and archives from the web and google drive

0.3.0 (2020-10-04)
-------------------

* addedd support for removing categories and other utilities

0.4.0 (2020-10-05)
-------------------

* addedd support to create a dataset from scratch

0.5.0 (2020-10-06)
-------------------

* added support to visualize images and annotations
* make image removing optional during annotations and categories deletion

0.6.0 (2020-10-12)
-------------------

* added copy dataset
* added split dataset